SNS_SUBSCRIPTION_NOTIFICATION = {
    "Type": "SubscriptionConfirmation",
    "MessageId": "ad01b87e-626a-443b-9b28-3c40ff5ebea5",
    "Token": "2336412f37fb687f5d51e6e241da92fd744699239e28eb25ebcef294aa79b3e339f26b7cc430ce0871bab7b13d28668befdbbf5597a17db06049c896cd457f1b2f3c582a403affaafb2ae9baa6d15d0afc51c0050f0d419a632d55d7a4a024d0d11953fac4753f008d78ea9c5085ef599c4e64846db77b760c00e4377a012448",
    "TopicArn": "arn:aws:sns:ap-southeast-2:919599206538:test-example",
    "Message": "You have chosen to subscribe to the topic arn:aws:sns:ap-southeast-2:919599206538:test-example.\nTo confirm the subscription, visit the SubscribeURL included in this message.",
    "SubscribeURL": "https://sns.ap-southeast-2.amazonaws.com/?Action=ConfirmSubscription&TopicArn=arn:aws:sns:ap-southeast-2:919599206538:test-example&Token=2336412f37fb687f5d51e6e241da92fd744699239e28eb25ebcef294aa79b3e339f26b7cc430ce0871bab7b13d28668befdbbf5597a17db06049c896cd457f1b2f3c582a403affaafb2ae9baa6d15d0afc51c0050f0d419a632d55d7a4a024d0d11953fac4753f008d78ea9c5085ef599c4e64846db77b760c00e4377a012448",
    "Timestamp": "2018-01-07T04:07:16.301Z",
    "SignatureVersion": "1",
    "Signature": "Ps5DODb4HQyVeZnuqnjMxwAXo1xg2/cPiXJ53quM/LzxUYbeh5tWmtOZr5l/kvgVe1DECaEYS5cSgwTrFjEJBt+M1EVXK4AaeiHyzk8LlghA5dhoICg+wkS3kHiQYKvU/JczGODImx0qA2e2HnAZ3DqPb+sY3EI10xebvnsvHoHJ6YqnJdC6L5vjFj6SW1xb+2oAo/teHeZYm/Fb7z17uGL06e80O43y+o/v4M8lZ1qZsUWZzluP48GciBegw4++AWUxNzEZSZKoV3AzCjObLeUHVI6bwTf9+xpKU9vhPPbLwIJyOUXEKlJQEPqgRoFkB+Ts60q2Ikg7h54QZW5CGQ==",
    "SigningCertURL": "https://sns.ap-southeast-2.amazonaws.com/SimpleNotificationService-433026a4050d206028891664da859041.pem",
}

SNS_UNSUBSCRIBE_NOTIFICATION = {
    "Type": "UnsubscribeConfirmation",
    "MessageId": "ad01b87e-626a-443b-9b28-3c40ff5ebea5",
    "Token": "2336412f37fb687f5d51e6e241da92fd744699239e28eb25ebcef294aa79b3e339f26b7cc430ce0871bab7b13d28668befdbbf5597a17db06049c896cd457f1b2f3c582a403affaafb2ae9baa6d15d0afc51c0050f0d419a632d55d7a4a024d0d11953fac4753f008d78ea9c5085ef599c4e64846db77b760c00e4377a012448",
    "TopicArn": "arn:aws:sns:ap-southeast-2:919599206538:test-example",
    "Message": "You have chosen to subscribe to the topic arn:aws:sns:ap-southeast-2:919599206538:test-example.\nTo confirm the subscription, visit the SubscribeURL included in this message.",
    "SubscribeURL": "https://sns.ap-southeast-2.amazonaws.com/?Action=ConfirmSubscription&TopicArn=arn:aws:sns:ap-southeast-2:919599206538:test-example&Token=2336412f37fb687f5d51e6e241da92fd744699239e28eb25ebcef294aa79b3e339f26b7cc430ce0871bab7b13d28668befdbbf5597a17db06049c896cd457f1b2f3c582a403affaafb2ae9baa6d15d0afc51c0050f0d419a632d55d7a4a024d0d11953fac4753f008d78ea9c5085ef599c4e64846db77b760c00e4377a012448",
    "Timestamp": "2018-01-07T04:07:16.301Z",
    "SignatureVersion": "1",
    "Signature": "Ps5DODb4HQyVeZnuqnjMxwAXo1xg2/cPiXJ53quM/LzxUYbeh5tWmtOZr5l/kvgVe1DECaEYS5cSgwTrFjEJBt+M1EVXK4AaeiHyzk8LlghA5dhoICg+wkS3kHiQYKvU/JczGODImx0qA2e2HnAZ3DqPb+sY3EI10xebvnsvHoHJ6YqnJdC6L5vjFj6SW1xb+2oAo/teHeZYm/Fb7z17uGL06e80O43y+o/v4M8lZ1qZsUWZzluP48GciBegw4++AWUxNzEZSZKoV3AzCjObLeUHVI6bwTf9+xpKU9vhPPbLwIJyOUXEKlJQEPqgRoFkB+Ts60q2Ikg7h54QZW5CGQ==",
    "SigningCertURL": "https://sns.ap-southeast-2.amazonaws.com/SimpleNotificationService-433026a4050d206028891664da859041.pem",
}

SNS_NOTIFICATION = {
    "Type": "Notification",
    "MessageId": "62acea4d-630a-5a7f-8a4e-b886c17258dd",
    "TopicArn": "arn:aws:sns:ap-southeast-2:919599206538:test-example",
    "Subject": "With Subject",
    "Message": '{"hello": "world"}',
    "Timestamp": "2018-01-07T04:21:12.742Z",
    "SignatureVersion": "1",
    "Signature": "V0APJSXwl5ubpJYJUVeV8PfP7LVnVWk7+W/J2KITo2ZIQlS4Z3KQ/o2nTci6Dg+v+IzDGBmFS2SNBZJiikXtTVvJeqRIb3uqKs2aDSH+cm8PphJhkhfoxNTcwD6J1n3uEgVz7n7ZdHphQGfGuKVT9d8IbPeczBKZ8twB7HLlr/v5NhMpRhYqYMypm916rO5hgyWaDqO3w5o3mzYLevYW4KuhMvdwLOQxslF+SCUSbQGqAbgm5jY1XZxN5wv0bF/3BgXJirmlMOTmk0O+xkTj4rhs2u9vlfMV5thRXqCo7LUSIGGMuXvBjxAF9Ph/QcKTFIHlitBgjWKfdoUWeblNkg==",
    "SigningCertURL": "https://sns.ap-southeast-2.amazonaws.com/SimpleNotificationService-433026a4050d206028891664da859041.pem",
    "UnsubscribeURL": "https://sns.ap-southeast-2.amazonaws.com/?Action=Unsubscribe&SubscriptionArn=arn:aws:sns:ap-southeast-2:919599206538:test-example:358ec852-8d21-4777-8175-0433ad263cb3",
    "MessageAttributes": {
        "AWS.SNS.MOBILE.MPNS.Type": {"Type": "String", "Value": "token"},
        "AWS.SNS.MOBILE.MPNS.NotificationClass": {
            "Type": "String",
            "Value": "realtime",
        },
        "AWS.SNS.MOBILE.WNS.Type": {"Type": "String", "Value": "wns/badge"},
    },
}

SNS_NOTIFICATION_NO_SUBJECT = {
    "Type": "Notification",
    "MessageId": "cd2fe5d6-f321-5602-b250-b71d51fd1689",
    "TopicArn": "arn:aws:sns:ap-southeast-2:919599206538:test-example",
    "Message": '{"hello": "world"}',
    "Timestamp": "2018-01-07T04:22:52.993Z",
    "SignatureVersion": "1",
    "Signature": "ivW/VU2bxFcAkvAqx+PAor33My/jsXIxcz9vRvU4k2u2uctXLT4GvNqYhim4ISdRZ8yXKnaHkWa/K3N2awf9KWfpXnshRlvAAnPcIXRrIAXFy49I0V9/grjYJOsKDkKS/jXh23AfhUfLNyltjDqpY1Fy9a5c7OqU7zLYJmjtTQQSOr3uMV7RsEtbx0M1SO3z9TeF7N7bXGxoKZboFx2jxSjSeuMRMvjlX/ut7fMyFbyuiXhkEg1WXJRuBLWqeistVdVPLr1r5ol8bwUiLOkjnG1xSB21H5Y2LCp5PcxPY6Bhg7VSiSNX1FPLFQdQ8s5AViOYir+VReE4KEuB7prduw==",
    "SigningCertURL": "https://sns.ap-southeast-2.amazonaws.com/SimpleNotificationService-433026a4050d206028891664da859041.pem",
    "UnsubscribeURL": "https://sns.ap-southeast-2.amazonaws.com/?Action=Unsubscribe&SubscriptionArn=arn:aws:sns:ap-southeast-2:919599206538:test-example:358ec852-8d21-4777-8175-0433ad263cb3",
    "MessageAttributes": {
        "AWS.SNS.MOBILE.MPNS.Type": {"Type": "String", "Value": "token"},
        "AWS.SNS.MOBILE.MPNS.NotificationClass": {
            "Type": "String",
            "Value": "realtime",
        },
        "AWS.SNS.MOBILE.WNS.Type": {"Type": "String", "Value": "wns/badge"},
    },
}
